==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/TumblingWindowTriggerDependencyReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerDependencyReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Referenced tumbling window trigger dependency.
 * @property offset Timespan applied to the start time of a tumbling window when evaluating dependency.
 * @property referenceTrigger Referenced trigger.
 * @property size The size of the window when evaluating the dependency. If undefined the frequency of the tumbling window will be used.
 * @property type The type of dependency reference.
 * Expected value is 'TumblingWindowTriggerDependencyReference'.
 */
public data class TumblingWindowTriggerDependencyReferenceArgs(
    public val offset: Output<String>? = null,
    public val referenceTrigger: Output<TriggerReferenceArgs>,
    public val size: Output<String>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerDependencyReferenceArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerDependencyReferenceArgs =
        com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerDependencyReferenceArgs.builder()
            .offset(offset?.applyValue({ args0 -> args0 }))
            .referenceTrigger(referenceTrigger.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .size(size?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TumblingWindowTriggerDependencyReferenceArgs].
 */
@PulumiTagMarker
public class TumblingWindowTriggerDependencyReferenceArgsBuilder internal constructor() {
    private var offset: Output<String>? = null

    private var referenceTrigger: Output<TriggerReferenceArgs>? = null

    private var size: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value Timespan applied to the start time of a tumbling window when evaluating dependency.
     */
    @JvmName("asvwtkrnapxyemfa")
    public suspend fun offset(`value`: Output<String>) {
        this.offset = value
    }

    /**
     * @param value Referenced trigger.
     */
    @JvmName("nfseshxjiqndcarj")
    public suspend fun referenceTrigger(`value`: Output<TriggerReferenceArgs>) {
        this.referenceTrigger = value
    }

    /**
     * @param value The size of the window when evaluating the dependency. If undefined the frequency of the tumbling window will be used.
     */
    @JvmName("icsijndbboyhvqnu")
    public suspend fun size(`value`: Output<String>) {
        this.size = value
    }

    /**
     * @param value The type of dependency reference.
     * Expected value is 'TumblingWindowTriggerDependencyReference'.
     */
    @JvmName("kfavfwkjfhlcnmel")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Timespan applied to the start time of a tumbling window when evaluating dependency.
     */
    @JvmName("gybhcoxoceciscwp")
    public suspend fun offset(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.offset = mapped
    }

    /**
     * @param value Referenced trigger.
     */
    @JvmName("xrsncvmbtwttguwn")
    public suspend fun referenceTrigger(`value`: TriggerReferenceArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.referenceTrigger = mapped
    }

    /**
     * @param argument Referenced trigger.
     */
    @JvmName("calfuauipbfttfxj")
    public suspend fun referenceTrigger(argument: suspend TriggerReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = TriggerReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.referenceTrigger = mapped
    }

    /**
     * @param value The size of the window when evaluating the dependency. If undefined the frequency of the tumbling window will be used.
     */
    @JvmName("huhdimkxsdjyvdra")
    public suspend fun size(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.size = mapped
    }

    /**
     * @param value The type of dependency reference.
     * Expected value is 'TumblingWindowTriggerDependencyReference'.
     */
    @JvmName("qgkbxyhmicrwmasw")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): TumblingWindowTriggerDependencyReferenceArgs =
        TumblingWindowTriggerDependencyReferenceArgs(
            offset = offset,
            referenceTrigger = referenceTrigger ?: throw PulumiNullFieldException("referenceTrigger"),
            size = size,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/TumblingWindowTriggerDependencyReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerDependencyReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Referenced tumbling window trigger dependency.
 * @property offset Timespan applied to the start time of a tumbling window when evaluating dependency.
 * @property referenceTrigger Referenced trigger.
 * @property size The size of the window when evaluating the dependency. If undefined the frequency of the tumbling window will be used.
 * @property type The type of dependency reference.
 * Expected value is 'TumblingWindowTriggerDependencyReference'.
 */
public data class TumblingWindowTriggerDependencyReferenceArgs(
    public val offset: Output<String>? = null,
    public val referenceTrigger: Output<TriggerReferenceArgs>,
    public val size: Output<String>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerDependencyReferenceArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerDependencyReferenceArgs =
        com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerDependencyReferenceArgs.builder()
            .offset(offset?.applyValue({ args0 -> args0 }))
            .referenceTrigger(referenceTrigger.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .size(size?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TumblingWindowTriggerDependencyReferenceArgs].
 */
@PulumiTagMarker
public class TumblingWindowTriggerDependencyReferenceArgsBuilder internal constructor() {
    private var offset: Output<String>? = null

    private var referenceTrigger: Output<TriggerReferenceArgs>? = null

    private var size: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value Timespan applied to the start time of a tumbling window when evaluating dependency.
     */
    @JvmName("valralmajnitctyo")
    public suspend fun offset(`value`: Output<String>) {
        this.offset = value
    }

    /**
     * @param value Referenced trigger.
     */
    @JvmName("hldykdydewndkrsf")
    public suspend fun referenceTrigger(`value`: Output<TriggerReferenceArgs>) {
        this.referenceTrigger = value
    }

    /**
     * @param value The size of the window when evaluating the dependency. If undefined the frequency of the tumbling window will be used.
     */
    @JvmName("kpdbyqsjstedmdji")
    public suspend fun size(`value`: Output<String>) {
        this.size = value
    }

    /**
     * @param value The type of dependency reference.
     * Expected value is 'TumblingWindowTriggerDependencyReference'.
     */
    @JvmName("yrxyahaovgobjjlg")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Timespan applied to the start time of a tumbling window when evaluating dependency.
     */
    @JvmName("girsbgebucwxdtbq")
    public suspend fun offset(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.offset = mapped
    }

    /**
     * @param value Referenced trigger.
     */
    @JvmName("emcvpinltiowietg")
    public suspend fun referenceTrigger(`value`: TriggerReferenceArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.referenceTrigger = mapped
    }

    /**
     * @param argument Referenced trigger.
     */
    @JvmName("esrbmjweurtgjkha")
    public suspend fun referenceTrigger(argument: suspend TriggerReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = TriggerReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.referenceTrigger = mapped
    }

    /**
     * @param value The size of the window when evaluating the dependency. If undefined the frequency of the tumbling window will be used.
     */
    @JvmName("dlmoeundrmftequt")
    public suspend fun size(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.size = mapped
    }

    /**
     * @param value The type of dependency reference.
     * Expected value is 'TumblingWindowTriggerDependencyReference'.
     */
    @JvmName("hxamrxvtseifhcnl")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): TumblingWindowTriggerDependencyReferenceArgs =
        TumblingWindowTriggerDependencyReferenceArgs(
            offset = offset,
            referenceTrigger = referenceTrigger ?: throw PulumiNullFieldException("referenceTrigger"),
            size = size,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}
